package jp.co.sds_corp.fxutil;

import java.io.Serializable;
import java.util.Properties;

/**
* 通貨ペアテーブル
*/
public class CcyPair implements Serializable
{
	private static final long serialVersionUID = 1L;
	Properties	prop = new Properties();

	/**
	* 通常は使用しないでください。
	*/
	public CcyPair( Ccy ccy1, Ccy ccy2 ) {
		this.ccy1 = ccy1;
		this.ccy2 = ccy2;
	}

	public CcyPair( Ccy ccy1, Ccy ccy2, Ccy cross, boolean feed,
					int point, int fwdPoint )
		throws Exception
	{
		this.ccy1 = ccy1;
		this.ccy2 = ccy2;
		this.cross = cross;
		if ( cross != null &&
			!cross.equals( ccy1 ) && !cross.equals( ccy2 ))
		{
			compound = true;
		}
		this.feed = feed;
		this.point = point;
		this.fwdPoint = fwdPoint;
	}

	/**
	* このCcyPairと指定されたCcyPairを比較します。
	* @param	o		比較するオブジェクト
	* @return	等しい場合のみtrue
	*/
	public boolean equals( Object o ) {
		if ( !(o instanceof CcyPair )) {
			return false;
		}
		CcyPair cmp = (CcyPair )o;
		if ( getCcy1().equals( cmp.getCcy1()) &&
			getCcy2().equals( cmp.getCcy2()))
		{
			return true;
		}
		return false;
	}

	/**
	* オブジェクトのハッシュコード値を返します。
	* @return	ハッシュコード値
	*/
	public int hashCode() {
		return ccy1.hashCode() + ccy2.hashCode();
	}

	public String toString() {
		return ccy1.getCode() + "/" + ccy2.getCode();
	}

	/**
	* 指定されたキーと値を設定します。
	* @param	key		キー
	* @param	value	値
	* @return	以前に設定されている値。無ければnull
	*/
	public Object setProperty( String key, String value ) {
		Object ret = prop.setProperty( key, value );
		return ret;
	}
	/**
	* 指定されたキーを持つプロパティを、プロパティリストから探します。
	* @param	key		キー
	* @return	設定されている値
	*/
	public String getProperty( String key ) {
		String ret = prop.getProperty( key );
		return ret;
	}
	/**
	* 現在設定されているプロパティを取得します。
	* @return	設定されているプロパティ
	*/
	public Properties getProperties() {
		return prop;
	}

	Ccy	ccy1;	// 通貨1
	Ccy	ccy2;	// 通貨2
	Ccy	cross;	// クロス通貨
	boolean	compound;	// 合成フラグ
	boolean	feed;	// フィードフラグ
	int	point;	// 小数点桁数
	int	fwdPoint;	// Forward小数点桁数

	/**
	* 通貨1を設定します。
	* @param	var		設定するデータ
	*/
	public void setCcy1( Ccy var ) {
		this.ccy1 = var;
	}
	/**
	* 通貨1を取得します。
	* @return	通貨1
	*/
	public Ccy getCcy1() {
		return ccy1;
	}

	/**
	* 通貨2を設定します。
	* @param	var		設定するデータ
	*/
	public void setCcy2( Ccy var ) {
		this.ccy2 = var;
	}
	/**
	* 通貨2を取得します。
	* @return	通貨2
	*/
	public Ccy getCcy2() {
		return ccy2;
	}

	/**
	* クロス通貨を設定します。
	* @param	var		設定するデータ
	*/
	public void setCross( Ccy var ) {
		this.cross = var;
	}
	/**
	* クロス通貨を取得します。
	* @return	クロス通貨
	*/
	public Ccy getCross() {
		return cross;
	}

	/**
	* 合成フラグを設定します。
	* @param	var		設定するデータ
	*/
	public void setCompound( boolean var ) {
		this.compound = var;
	}
	/**
	* 合成フラグを取得します。
	* @return	合成フラグ
	*/
	public boolean isCompound() {
		return compound;
	}

	/**
	* フィードフラグを設定します。
	* @param	var		設定するデータ
	*/
	public void setFeed( boolean var ) {
		this.feed = var;
	}
	/**
	* フィードフラグを取得します。
	* @return	フィードフラグ
	*/
	public boolean isFeed() {
		return feed;
	}

	/**
	* 小数点桁数を設定します。
	* @param	var		設定するデータ
	*/
	public void setPoint( int var ) {
		this.point = var;
	}
	/**
	* 小数点桁数を取得します。
	* @return	小数点桁数
	*/
	public int getPoint() {
		return point;
	}

	/**
	* Forward小数点桁数を設定します。
	* @param	var		設定するデータ
	*/
	public void setFwdPoint( int var ) {
		this.fwdPoint = var;
	}
	/**
	* Forward小数点桁数を取得します。
	* @return	Forward小数点桁数
	*/
	public int getFwdPoint() {
		return fwdPoint;
	}

}
