package jp.co.sds_corp.fxutil;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Properties;

public class ForexRate implements Cloneable
{
	Properties	prop = new Properties();

	public ForexRate( CcyPair pair, Date valueDate ) {
		this( pair, null, valueDate );
	}

	public ForexRate( CcyPair pair, String term ) {
		this.pair = pair;
		this.term = term;
		this.valueDate = new Date(); // @@@ 自動計算？
		this.updateTime = new Date();
	}

	public ForexRate( CcyPair pair, String term, Date valueDate ) {
		this.pair = pair;
		this.term = term;
		this.valueDate = valueDate;
		this.updateTime = new Date();
	}

	public void updateTime() {
		updateTime = new Date();
	}

	/**
	* 指定されたキーと値を設定します。
	* @param	key		キー
	* @param	value	値
	* @return	以前に設定されている値。無ければnull
	*/
	public Object setProperty( String key, String value ) {
		Object ret = prop.setProperty( key, value );
		return ret;
	}
	/**
	* 指定されたキーを持つプロパティを、プロパティリストから探します。
	* @param	key		キー
	* @return	設定されている値
	*/
	public String getProperty( String key ) {
		String ret = prop.getProperty( key );
		return ret;
	}
	/**
	* 現在設定されているプロパティを取得します。
	* @return	設定されているプロパティ
	*/
	public Properties getProperties() {
		return prop;
	}

	public String toString() {
		String ret =  pair + ":" + term +":"+ bid +":"+ ask;
		if ( prop.size() > 0 ) {
			ret += ":" + prop.toString();
		}
		SimpleDateFormat sdf = new SimpleDateFormat( "yyyy/MM/dd HH:mm:ss" );
		ret += ":" + sdf.format( updateTime );
		return ret;
	}

	CcyPair	pair;	// 通貨ペア
	String	term;	// 期間コード
	Date	valueDate;	// 受渡日
	BigDecimal	bid;	// bidレート
	BigDecimal	ask;	// askレート
	Date	updateTime;	// 更新日時

	/**
	* 通貨ペアを設定します。
	* @param	var		設定するデータ
	*/
	public void setPair( CcyPair var ) {
		this.pair = var;
	}
	/**
	* 通貨ペアを取得します。
	* @return	通貨ペア
	*/
	public CcyPair getPair() {
		return pair;
	}

	/**
	* 期間コードを設定します。
	* @param	var		設定するデータ
	*/
	public void setTerm( String var ) {
		this.term = var;
	}
	/**
	* 期間コードを取得します。
	* @return	期間コード
	*/
	public String getTerm() {
		return term;
	}

	/**
	* 受渡日を設定します。
	* @param	var		設定するデータ
	*/
	public void setValueDate( Date var ) {
		this.valueDate = var;
	}
	/**
	* 受渡日を取得します。
	* @return	受渡日
	*/
	public Date getValueDate() {
		return valueDate;
	}

	/**
	* bidレートを設定します。
	* @param	var		設定するデータ
	*/
	public void setBid( BigDecimal var ) {
		this.bid = var;
	}
	/**
	* bidレートを取得します。
	* @return	bidレート
	*/
	public BigDecimal getBid() {
		return bid;
	}

	/**
	* askレートを設定します。
	* @param	var		設定するデータ
	*/
	public void setAsk( BigDecimal var ) {
		this.ask = var;
	}
	/**
	* askレートを取得します。
	* @return	askレート
	*/
	public BigDecimal getAsk() {
		return ask;
	}

	/**
	* 更新日時を設定します。
	* @param	var		設定するデータ
	*/
	public void setUpdateTime( Date var ) {
		this.updateTime = var;
	}
	/**
	* 更新日時を取得します。
	* @return	更新日時
	*/
	public Date getUpdateTime() {
		return updateTime;
	}

}
