package	jp.co.sds_corp.fxutil.service;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.net.URL;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import jp.co.sds_corp.fxutil.Ccy;
import jp.co.sds_corp.fxutil.cache.CalendarCache;
import jp.co.sds_corp.util.common.CmnString;
import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.log.CmnLogFactory;
import jp.co.sds_corp.util.log.CmnLogger;

/**
* 休日マスタのローダです。
*/
public class CsvCalendarLoader extends CsvLoader
{
	static final CmnLogger logger = CmnLogFactory.getLogger();

	public void init( IConfiguration config ) throws Exception {
		super.init( config );
		URL url;
		url = getUrl( config );
		if ( url != null ) {
			HashMap<Ccy,Map<Date,Boolean>> map = new HashMap<Ccy,Map<Date,Boolean>>();
			BufferedReader rd = new BufferedReader(
								new InputStreamReader( url.openStream()));
			for ( ;; ) {
				String buf = rd.readLine();
				if ( buf == null ) {
					break;
				}
				String[] line = CmnString.getStringToken( buf, "\t" );
				Holiday hol = parseHoliday( line );
				if ( hol.ccy == null ) {
					continue;
				}
				Map<Date,Boolean> mapCcy = map.get( hol.ccy );
				if ( mapCcy == null ) {
					mapCcy = new HashMap<Date,Boolean>();
					map.put( hol.ccy, mapCcy );
				}
				mapCcy.put( hol.date, Boolean.valueOf( true ));
				if ( isDebug()) {
					logger.debug( this, "add holiday [" + hol.ccy + ":" + hol.date + "]" );
				}
			}
			CalendarCache cache = master.getCalendarCache();
			cache.mapHoliday().clear();
			cache.mapHoliday().putAll( map );
		}
	}

	class Holiday
	{
		Ccy		ccy;
		Date	date;
	}

	protected Holiday parseHoliday( String[] line ) throws Exception {
		String code = line[0];
		String sd = line[1];
		Ccy ccy = master.getCcy( code );
		SimpleDateFormat sdf = new SimpleDateFormat( "yyyy-MM-dd" );
		Date date = sdf.parse( sd );
		Holiday ret = new Holiday();
		ret.ccy = ccy;
		ret.date = date;
		return ret;
	}

}
